package com.chelvc.framework.common.model;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.chelvc.framework.common.util.BeanCopyUtil;
import lombok.Data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * 分页视图
 *
 * @author 武尊
 * @date 2023/04/16 23:09
 */
@Data
public class PagedVO<T> implements Serializable {

  private static final long serialVersionUID = 3889341994334964174L;

  /**
   * 总数
   */
  private Long totalNumber;

  /**
   * 页码
   */
  private Long pageNumber;

  /**
   * 页面大小
   */
  private Long pageSize;

  /**
   * 数据记录
   */
  private List<T> records;

  public static <T, S> PagedVO<S> build(IPage<T> dataSource, Class<S> targetClazz) {
    PagedVO<S> result = new PagedVO<>();
    result.setTotalNumber(dataSource.getTotal());
    result.setPageNumber(dataSource.getCurrent());
    result.setPageSize(dataSource.getSize());
    List<S> records = new ArrayList<>();
    for (T t : dataSource.getRecords()) {
      S s = BeanCopyUtil.copy(t, targetClazz);
      records.add(s);
    }
    result.setRecords(records);
    return result;
  }
}
